@@ -88,6 +88,7 @@ if TYPE_CHECKING:  # pragma: no cover
 
 class BrowserContext(ChannelOwner):
     Events = SimpleNamespace(
+        # Deprecated in v1.56, never emitted anymore.
         BackgroundPage="backgroundpage",
         Close="close",
         Console="console",
@@ -117,8 +118,9 @@ class BrowserContext(ChannelOwner):
         self._timeout_settings = TimeoutSettings(None)
         self._owner_page: Optional[Page] = None
         self._options: Dict[str, Any] = initializer["options"]
-        self._background_pages: Set[Page] = set()
         self._service_workers: Set[Worker] = set()
+        self._base_url: Optional[str] = self._options.get("baseURL")
+        self._videos_dir: Optional[str] = self._options.get("recordVideo")
         self._tracing = cast(Tracing, from_channel(initializer["tracing"]))
         self._har_recorders: Dict[str, HarRecordingMetadata] = {}
         self._request: APIRequestContext = from_channel(initializer["requestContext"])
@@ -147,10 +149,6 @@ class BrowserContext(ChannelOwner):
                 )
             ),
         )
-        self._channel.on(
-            "backgroundPage",
-            lambda params: self._on_background_page(from_channel(params["page"])),
-        )
 
         self._channel.on(
             "serviceWorker",
@@ -424,7 +422,7 @@ class BrowserContext(ChannelOwner):
         self._routes.insert(
             0,
             RouteHandler(
-                self._options.get("baseURL"),
+                self._base_url,
                 url,
                 handler,
                 True if self._dispatcher_fiber else False,
@@ -452,17 +450,16 @@ class BrowserContext(ChannelOwner):
         behavior: Literal["default", "ignoreErrors", "wait"] = None,
     ) -> None:
         self._routes = remaining
+        if behavior is not None and behavior != "default":
+            await asyncio.gather(*map(lambda router: router.stop(behavior), removed))  # type: ignore
         await self._update_interception_patterns()
-        if behavior is None or behavior == "default":
-            return
-        await asyncio.gather(*map(lambda router: router.stop(behavior), removed))  # type: ignore
 
     async def route_web_socket(
         self, url: URLMatch, handler: WebSocketRouteHandlerCallback
     ) -> None:
         self._web_socket_routes.insert(
             0,
-            WebSocketRouteHandler(self._options.get("baseURL"), url, handler),
+            WebSocketRouteHandler(self._base_url, url, handler),
         )
         await self._update_web_socket_interception_patterns()
 
@@ -657,10 +654,6 @@ class BrowserContext(ChannelOwner):
     ) -> EventContextManagerImpl[Page]:
         return self.expect_event(BrowserContext.Events.Page, predicate, timeout)
 
-    def _on_background_page(self, page: Page) -> None:
-        self._background_pages.add(page)
-        self.emit(BrowserContext.Events.BackgroundPage, page)
-
     def _on_service_worker(self, worker: Worker) -> None:
         worker._context = self
         self._service_workers.add(worker)
@@ -735,7 +728,7 @@ class BrowserContext(ChannelOwner):
 
     @property
     def background_pages(self) -> List[Page]:
-        return list(self._background_pages)
+        return []
 
     @property
     def service_workers(self) -> List[Worker]:
