@@ -49,8 +49,8 @@ class BrowserServerLauncherImpl {
     const playwright = (0, import_playwright.createPlaywright)({ sdkLanguage: "javascript", isServer: true });
     const metadata = { id: "", startTime: 0, endTime: 0, type: "Internal", method: "", params: {}, log: [], internal: true };
     const validatorContext = {
-      tChannelImpl: (names, arg, path) => {
-        throw new validatorPrimitives.ValidationError(`${path}: channels are not expected in launchServer`);
+      tChannelImpl: (names, arg, path2) => {
+        throw new validatorPrimitives.ValidationError(`${path2}: channels are not expected in launchServer`);
       },
       binary: "buffer",
       isUnderTest: import_debug.isUnderTest
@@ -82,11 +82,8 @@ class BrowserServerLauncherImpl {
       (0, import_stackTrace.rewriteErrorMessage)(e, `${e.message} Failed to launch browser.${log}`);
       throw e;
     }
-    return this.launchServerOnExistingBrowser(browser, options);
-  }
-  async launchServerOnExistingBrowser(browser, options) {
     const path = options.wsPath ? options.wsPath.startsWith("/") ? options.wsPath : `/${options.wsPath}` : `/${(0, import_crypto.createGuid)()}`;
-    const server = new import_playwrightServer.PlaywrightServer({ mode: options._sharedBrowser ? "launchServerShared" : "launchServer", path, maxConnections: Infinity, preLaunchedBrowser: browser, debugController: options._debugController });
+    const server = new import_playwrightServer.PlaywrightServer({ mode: options._sharedBrowser ? "launchServerShared" : "launchServer", path, maxConnections: Infinity, preLaunchedBrowser: browser });
     const wsEndpoint = await server.listen(options.port, options.host);
     const browserServer = new import_utilsBundle.ws.EventEmitter();
     browserServer.process = () => browser.options.browserProcess.process;
