@@ -67,7 +67,6 @@ class BrowserContext extends import_channelOwner.ChannelOwner {
     this._browser = null;
     this._bindings = /* @__PURE__ */ new Map();
     this._forReuse = false;
-    this._backgroundPages = /* @__PURE__ */ new Set();
     this._serviceWorkers = /* @__PURE__ */ new Set();
     this._harRecorders = /* @__PURE__ */ new Map();
     this._closingStatus = "none";
@@ -83,11 +82,6 @@ class BrowserContext extends import_channelOwner.ChannelOwner {
     this._channel.on("page", ({ page }) => this._onPage(import_page.Page.from(page)));
     this._channel.on("route", ({ route }) => this._onRoute(network.Route.from(route)));
     this._channel.on("webSocketRoute", ({ webSocketRoute }) => this._onWebSocketRoute(network.WebSocketRoute.from(webSocketRoute)));
-    this._channel.on("backgroundPage", ({ page }) => {
-      const backgroundPage = import_page.Page.from(page);
-      this._backgroundPages.add(backgroundPage);
-      this.emit(import_events.Events.BrowserContext.BackgroundPage, backgroundPage);
-    });
     this._channel.on("serviceWorker", ({ worker }) => {
       const serviceWorker = import_worker.Worker.from(worker);
       serviceWorker._context = this;
@@ -95,7 +89,7 @@ class BrowserContext extends import_channelOwner.ChannelOwner {
       this.emit(import_events.Events.BrowserContext.ServiceWorker, serviceWorker);
     });
     this._channel.on("console", (event) => {
-      const consoleMessage = new import_consoleMessage.ConsoleMessage(this._platform, event);
+      const consoleMessage = new import_consoleMessage.ConsoleMessage(this._platform, event, import_page.Page.fromNullable(event.page));
       this.emit(import_events.Events.BrowserContext.Console, consoleMessage);
       const page = consoleMessage.page();
       if (page)
@@ -402,7 +396,7 @@ class BrowserContext extends import_channelOwner.ChannelOwner {
     return state;
   }
   backgroundPages() {
-    return [...this._backgroundPages];
+    return [];
   }
   serviceWorkers() {
     return [...this._serviceWorkers];
