@@ -30,7 +30,8 @@ var bidiBrowser_exports = {};
 __export(bidiBrowser_exports, {
   BidiBrowser: () => BidiBrowser,
   BidiBrowserContext: () => BidiBrowserContext,
-  Network: () => Network
+  Network: () => Network,
+  getScreenOrientation: () => getScreenOrientation
 });
 module.exports = __toCommonJS(bidiBrowser_exports);
 var import_eventsHelper = require("../utils/eventsHelper");
@@ -58,38 +59,11 @@ class BidiBrowser extends import_browser.Browser {
     const browser = new BidiBrowser(parent, transport, options);
     if (options.__testHookOnConnectToBrowser)
       await options.__testHookOnConnectToBrowser();
-    let proxy;
-    if (options.proxy) {
-      proxy = {
-        proxyType: "manual"
-      };
-      const url = new URL(options.proxy.server);
-      switch (url.protocol) {
-        case "http:":
-          proxy.httpProxy = url.host;
-          break;
-        case "https:":
-          proxy.httpsProxy = url.host;
-          break;
-        case "socks4:":
-          proxy.socksProxy = url.host;
-          proxy.socksVersion = 4;
-          break;
-        case "socks5:":
-          proxy.socksProxy = url.host;
-          proxy.socksVersion = 5;
-          break;
-        default:
-          throw new Error("Invalid proxy server protocol: " + options.proxy.server);
-      }
-      if (options.proxy.bypass)
-        proxy.noProxy = options.proxy.bypass.split(",");
-    }
     browser._bidiSessionInfo = await browser._browserSession.send("session.new", {
       capabilities: {
         alwaysMatch: {
-          acceptInsecureCerts: false,
-          proxy,
+          acceptInsecureCerts: options.persistent?.internalIgnoreHTTPSErrors || options.persistent?.ignoreHTTPSErrors,
+          proxy: getProxyConfiguration(options.originalLaunchOptions.proxyOverride ?? options.proxy),
           unhandledPromptBehavior: {
             default: bidi.Session.UserPromptHandlerType.Ignore
           },
@@ -105,6 +79,11 @@ class BidiBrowser extends import_browser.Browser {
         "script"
       ]
     });
+    await browser._browserSession.send("network.addDataCollector", {
+      dataTypes: [bidi.Network.DataType.Response],
+      maxEncodedDataSize: 2e7
+      // same default as in CDP: https://source.chromium.org/chromium/chromium/src/+/main:third_party/blink/renderer/core/inspector/inspector_network_agent.cc;l=134;drc=4128411589187a396829a827f59a655bed876aa7
+    });
     if (options.persistent) {
       const context = new BidiBrowserContext(browser, void 0, options.persistent);
       browser._defaultContext = context;
@@ -118,8 +97,10 @@ class BidiBrowser extends import_browser.Browser {
     this._didClose();
   }
   async doCreateNewContext(options) {
+    const proxy = options.proxyOverride || options.proxy;
     const { userContext } = await this._browserSession.send("browser.createUserContext", {
-      acceptInsecureCerts: options.ignoreHTTPSErrors
+      acceptInsecureCerts: options.internalIgnoreHTTPSErrors || options.ignoreHTTPSErrors,
+      proxy: getProxyConfiguration(proxy)
     });
     const context = new BidiBrowserContext(this, userContext, options);
     await context._initialize();
@@ -195,7 +176,6 @@ class BidiBrowserContext extends import_browserContext.BrowserContext {
   constructor(browser, browserContextId, options) {
     super(browser, options, browserContextId);
     this._originToPermissions = /* @__PURE__ */ new Map();
-    this._blockingPageCreations = /* @__PURE__ */ new Set();
     this._initScriptIds = /* @__PURE__ */ new Map();
     this._authenticateProxyViaHeader();
   }
@@ -206,46 +186,38 @@ class BidiBrowserContext extends import_browserContext.BrowserContext {
     const promises = [
       super._initialize()
     ];
-    if (this._options.viewport) {
-      promises.push(this._browser._browserSession.send("browsingContext.setViewport", {
-        viewport: {
-          width: this._options.viewport.width,
-          height: this._options.viewport.height
-        },
-        devicePixelRatio: this._options.deviceScaleFactor || 1,
+    promises.push(this.doUpdateDefaultViewport());
+    if (this._options.geolocation)
+      promises.push(this.setGeolocation(this._options.geolocation));
+    if (this._options.locale) {
+      promises.push(this._browser._browserSession.send("emulation.setLocaleOverride", {
+        locale: this._options.locale,
+        userContexts: [this._userContextId()]
+      }));
+    }
+    if (this._options.timezoneId) {
+      promises.push(this._browser._browserSession.send("emulation.setTimezoneOverride", {
+        timezone: this._options.timezoneId,
+        userContexts: [this._userContextId()]
+      }));
+    }
+    if (this._options.userAgent) {
+      promises.push(this._browser._browserSession.send("emulation.setUserAgentOverride", {
+        userAgent: this._options.userAgent,
         userContexts: [this._userContextId()]
       }));
     }
-    if (this._options.geolocation)
-      promises.push(this.setGeolocation(this._options.geolocation));
     await Promise.all(promises);
   }
   possiblyUninitializedPages() {
     return this._bidiPages().map((bidiPage) => bidiPage._page);
   }
-  async doCreateNewPage(markAsServerSideOnly) {
-    const promise = this._createNewPageImpl(markAsServerSideOnly);
-    if (markAsServerSideOnly)
-      this._blockingPageCreations.add(promise);
-    try {
-      return await promise;
-    } finally {
-      this._blockingPageCreations.delete(promise);
-    }
-  }
-  async _createNewPageImpl(markAsServerSideOnly) {
+  async doCreateNewPage() {
     const { context } = await this._browser._browserSession.send("browsingContext.create", {
       type: bidi.BrowsingContext.CreateType.Window,
       userContext: this._browserContextId
     });
-    const page = this._browser._bidiPages.get(context)._page;
-    if (markAsServerSideOnly)
-      page.markAsServerSideOnly();
-    return page;
-  }
-  async waitForBlockingPageCreations() {
-    await Promise.all([...this._blockingPageCreations].map((command) => command.catch(() => {
-    })));
+    return this._browser._bidiPages.get(context)._page;
   }
   async doGetCookies(urls) {
     const { cookies } = await this._browser._browserSession.send(
@@ -312,7 +284,7 @@ class BidiBrowserContext extends import_browserContext.BrowserContext {
       },
       state,
       origin,
-      userContext: this._browserContextId || "default"
+      userContext: this._userContextId()
     });
   }
   async setGeolocation(geolocation) {
@@ -324,14 +296,19 @@ class BidiBrowserContext extends import_browserContext.BrowserContext {
         longitude: geolocation.longitude,
         accuracy: geolocation.accuracy
       } : null,
-      userContexts: [this._browserContextId || "default"]
+      userContexts: [this._userContextId()]
     });
   }
-  async setExtraHTTPHeaders(headers) {
+  async doUpdateExtraHTTPHeaders() {
   }
   async setUserAgent(userAgent) {
+    this._options.userAgent = userAgent;
+    await this._browser._browserSession.send("emulation.setUserAgentOverride", {
+      userAgent: userAgent ?? null,
+      userContexts: [this._userContextId()]
+    });
   }
-  async setOffline(offline) {
+  async doUpdateOffline() {
   }
   async doSetHTTPCredentials(httpCredentials) {
     this._options.httpCredentials = httpCredentials;
@@ -342,7 +319,7 @@ class BidiBrowserContext extends import_browserContext.BrowserContext {
     const { script } = await this._browser._browserSession.send("script.addPreloadScript", {
       // TODO: remove function call from the source.
       functionDeclaration: `() => { return ${initScript.source} }`,
-      userContexts: [this._browserContextId || "default"]
+      userContexts: [this._userContextId()]
     });
     this._initScriptIds.set(initScript, script);
   }
@@ -358,6 +335,26 @@ class BidiBrowserContext extends import_browserContext.BrowserContext {
   }
   async doUpdateRequestInterception() {
   }
+  async doUpdateDefaultViewport() {
+    if (!this._options.viewport)
+      return;
+    await Promise.all([
+      this._browser._browserSession.send("browsingContext.setViewport", {
+        viewport: {
+          width: this._options.viewport.width,
+          height: this._options.viewport.height
+        },
+        devicePixelRatio: this._options.deviceScaleFactor || 1,
+        userContexts: [this._userContextId()]
+      }),
+      this._browser._browserSession.send("emulation.setScreenOrientationOverride", {
+        screenOrientation: getScreenOrientation(!!this._options.isMobile, this._options.viewport),
+        userContexts: [this._userContextId()]
+      })
+    ]);
+  }
+  async doUpdateDefaultEmulatedMedia() {
+  }
   async doExposePlaywrightBinding() {
     const args = [{
       type: "channel",
@@ -417,6 +414,8 @@ function fromBidiSameSite(sameSite) {
       return "Lax";
     case "none":
       return "None";
+    case "default":
+      return "Lax";
   }
   return "None";
 }
@@ -431,6 +430,48 @@ function toBidiSameSite(sameSite) {
   }
   return bidi.Network.SameSite.None;
 }
+function getProxyConfiguration(proxySettings) {
+  if (!proxySettings)
+    return void 0;
+  const proxy = {
+    proxyType: "manual"
+  };
+  const url = new URL(proxySettings.server);
+  switch (url.protocol) {
+    case "http:":
+      proxy.httpProxy = url.host;
+      break;
+    case "https:":
+      proxy.sslProxy = url.host;
+      break;
+    case "socks4:":
+      proxy.socksProxy = url.host;
+      proxy.socksVersion = 4;
+      break;
+    case "socks5:":
+      proxy.socksProxy = url.host;
+      proxy.socksVersion = 5;
+      break;
+    default:
+      throw new Error("Invalid proxy server protocol: " + proxySettings.server);
+  }
+  const bypass = proxySettings.bypass ?? process.env.PLAYWRIGHT_PROXY_BYPASS_FOR_TESTING;
+  if (bypass)
+    proxy.noProxy = bypass.split(",");
+  return proxy;
+}
+function getScreenOrientation(isMobile, viewportSize) {
+  const screenOrientation = {
+    type: "landscape-primary",
+    natural: bidi.Emulation.ScreenOrientationNatural.Landscape
+  };
+  if (isMobile) {
+    screenOrientation.natural = bidi.Emulation.ScreenOrientationNatural.Portrait;
+    if (viewportSize.width <= viewportSize.height)
+      screenOrientation.type = "portrait-primary";
+  }
+  return screenOrientation;
+}
 var Network;
 ((Network2) => {
   let SameSite;
@@ -444,5 +485,6 @@ var Network;
 0 && (module.exports = {
   BidiBrowser,
   BidiBrowserContext,
-  Network
+  Network,
+  getScreenOrientation
 });
