@@ -35,6 +35,7 @@ module.exports = __toCommonJS(bidiPage_exports);
 var import_eventsHelper = require("../utils/eventsHelper");
 var dialog = __toESM(require("../dialog"));
 var dom = __toESM(require("../dom"));
+var import_bidiBrowser = require("./bidiBrowser");
 var import_page = require("../page");
 var import_bidiExecutionContext = require("./bidiExecutionContext");
 var import_bidiInput = require("./bidiInput");
@@ -45,6 +46,7 @@ const UTILITY_WORLD_NAME = "__playwright_utility_world__";
 const kPlaywrightBindingChannel = "playwrightChannel";
 class BidiPage {
   constructor(browserContext, bidiSession, opener) {
+    this._realmToWorkerContext = /* @__PURE__ */ new Map();
     this._sessionListeners = [];
     this._initScriptIds = /* @__PURE__ */ new Map();
     this._session = bidiSession;
@@ -70,6 +72,8 @@ class BidiPage {
       import_eventsHelper.eventsHelper.addEventListener(bidiSession, "browsingContext.historyUpdated", this._onHistoryUpdated.bind(this)),
       import_eventsHelper.eventsHelper.addEventListener(bidiSession, "browsingContext.domContentLoaded", this._onDomContentLoaded.bind(this)),
       import_eventsHelper.eventsHelper.addEventListener(bidiSession, "browsingContext.load", this._onLoad.bind(this)),
+      import_eventsHelper.eventsHelper.addEventListener(bidiSession, "browsingContext.downloadWillBegin", this._onDownloadWillBegin.bind(this)),
+      import_eventsHelper.eventsHelper.addEventListener(bidiSession, "browsingContext.downloadEnd", this._onDownloadEnded.bind(this)),
       import_eventsHelper.eventsHelper.addEventListener(bidiSession, "browsingContext.userPromptOpened", this._onUserPromptOpened.bind(this)),
       import_eventsHelper.eventsHelper.addEventListener(bidiSession, "log.entryAdded", this._onLogEntryAdded.bind(this))
     ];
@@ -105,6 +109,13 @@ class BidiPage {
     }
   }
   _onRealmCreated(realmInfo) {
+    if (realmInfo.type === "dedicated-worker") {
+      const delegate2 = new import_bidiExecutionContext.BidiExecutionContext(this._session, realmInfo);
+      const worker = new import_page.Worker(this._page, realmInfo.origin);
+      this._realmToWorkerContext.set(realmInfo.realm, worker.createExecutionContext(delegate2));
+      this._page.addWorker(realmInfo.realm, worker);
+      return;
+    }
     if (this._realmToContext.has(realmInfo.realm))
       return;
     if (realmInfo.type !== "window")
@@ -143,11 +154,17 @@ class BidiPage {
   }
   _onRealmDestroyed(params) {
     const context = this._realmToContext.get(params.realm);
-    if (!context)
-      return false;
-    this._realmToContext.delete(params.realm);
-    context.frame._contextDestroyed(context);
-    return true;
+    if (context) {
+      this._realmToContext.delete(params.realm);
+      context.frame._contextDestroyed(context);
+      return true;
+    }
+    const existed = this._realmToWorkerContext.delete(params.realm);
+    if (existed) {
+      this._page.removeWorker(params.realm);
+      return true;
+    }
+    return false;
   }
   // TODO: route the message directly to the browser
   _onBrowsingContextDestroyed(params) {
@@ -198,11 +215,47 @@ class BidiPage {
       event.defaultValue
     ));
   }
+  _onDownloadWillBegin(event) {
+    if (!event.navigation)
+      return;
+    this._page.frameManager.frameAbortedNavigation(event.context, "Download is starting");
+    let originPage = this._page.initializedOrUndefined();
+    if (!originPage && this._opener)
+      originPage = this._opener._page.initializedOrUndefined();
+    if (!originPage)
+      return;
+    this._browserContext._browser._downloadCreated(originPage, event.navigation, event.url, event.suggestedFilename);
+  }
+  _onDownloadEnded(event) {
+    if (!event.navigation)
+      return;
+    this._browserContext._browser._downloadFinished(event.navigation, event.status === "canceled" ? "canceled" : void 0);
+  }
   _onLogEntryAdded(params) {
+    if (params.type === "javascript" && params.level === "error") {
+      let errorName = "";
+      let errorMessage;
+      if (params.text?.includes(": ")) {
+        const index = params.text.indexOf(": ");
+        errorName = params.text.substring(0, index);
+        errorMessage = params.text.substring(index + 2);
+      } else {
+        errorMessage = params.text ?? void 0;
+      }
+      const error = new Error(errorMessage);
+      error.name = errorName;
+      error.stack = `${params.text}
+${params.stackTrace?.callFrames.map((f) => {
+        const location2 = `${f.url}:${f.lineNumber + 1}:${f.columnNumber + 1}`;
+        return f.functionName ? `    at ${f.functionName} (${location2})` : `    at ${location2}`;
+      }).join("\n")}`;
+      this._page.addPageError(error);
+      return;
+    }
     if (params.type !== "console")
       return;
     const entry = params;
-    const context = this._realmToContext.get(params.source.realm);
+    const context = this._realmToContext.get(params.source.realm) ?? this._realmToWorkerContext.get(params.source.realm);
     if (!context)
       return;
     const callFrame = params.stackTrace?.callFrames[0];
@@ -233,14 +286,20 @@ class BidiPage {
     if (!emulatedSize)
       return;
     const viewportSize = emulatedSize.viewport;
-    await this._session.send("browsingContext.setViewport", {
-      context: this._session.sessionId,
-      viewport: {
-        width: viewportSize.width,
-        height: viewportSize.height
-      },
-      devicePixelRatio: options.deviceScaleFactor || 1
-    });
+    await Promise.all([
+      this._session.send("browsingContext.setViewport", {
+        context: this._session.sessionId,
+        viewport: {
+          width: viewportSize.width,
+          height: viewportSize.height
+        },
+        devicePixelRatio: options.deviceScaleFactor || 1
+      }),
+      this._session.send("emulation.setScreenOrientationOverride", {
+        contexts: [this._session.sessionId],
+        screenOrientation: (0, import_bidiBrowser.getScreenOrientation)(!!options.isMobile, viewportSize)
+      })
+    ]);
   }
   async updateRequestInterception() {
     await this._networkManager.setRequestInterception(this._page.needsRequestInterception());
@@ -307,10 +366,17 @@ class BidiPage {
     await Promise.all(ids.map((script) => this._session.send("script.removePreloadScript", { script })));
   }
   async closePage(runBeforeUnload) {
-    await this._session.send("browsingContext.close", {
-      context: this._session.sessionId,
-      promptUnload: runBeforeUnload
-    });
+    if (runBeforeUnload) {
+      this._session.sendMayFail("browsingContext.close", {
+        context: this._session.sessionId,
+        promptUnload: runBeforeUnload
+      });
+    } else {
+      await this._session.send("browsingContext.close", {
+        context: this._session.sessionId,
+        promptUnload: runBeforeUnload
+      });
+    }
   }
   async setBackgroundColor(color) {
   }
