@@ -28,7 +28,8 @@ var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__ge
 var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
 var chromium_exports = {};
 __export(chromium_exports, {
-  Chromium: () => Chromium
+  Chromium: () => Chromium,
+  waitForReadyState: () => waitForReadyState
 });
 module.exports = __toCommonJS(chromium_exports);
 var import_fs = __toESM(require("fs"));
@@ -37,7 +38,6 @@ var import_path = __toESM(require("path"));
 var import_chromiumSwitches = require("./chromiumSwitches");
 var import_crBrowser = require("./crBrowser");
 var import_crConnection = require("./crConnection");
-var import_timeoutSettings = require("../timeoutSettings");
 var import_utils = require("../../utils");
 var import_ascii = require("../utils/ascii");
 var import_debugLogger = require("../utils/debugLogger");
@@ -46,7 +46,6 @@ var import_network = require("../utils/network");
 var import_userAgent = require("../utils/userAgent");
 var import_browserContext = require("../browserContext");
 var import_browserType = require("../browserType");
-var import_browserType2 = require("../browserType");
 var import_helper = require("../helper");
 var import_registry = require("../registry");
 var import_transport = require("../transport");
@@ -54,20 +53,15 @@ var import_crDevTools = require("./crDevTools");
 var import_browser = require("../browser");
 var import_fileUtils = require("../utils/fileUtils");
 var import_processLauncher = require("../utils/processLauncher");
-var import_progress = require("../progress");
 const ARTIFACTS_FOLDER = import_path.default.join(import_os.default.tmpdir(), "playwright-artifacts-");
 class Chromium extends import_browserType.BrowserType {
   constructor(parent) {
     super(parent, "chromium");
-    if ((0, import_utils.debugMode)())
+    if ((0, import_utils.debugMode)() === "inspector")
       this._devtools = this._createDevTools();
   }
-  async connectOverCDP(metadata, endpointURL, options) {
-    const controller = new import_progress.ProgressController(metadata, this);
-    controller.setLogName("browser");
-    return controller.run(async (progress) => {
-      return await this._connectOverCDPInternal(progress, endpointURL, options);
-    }, import_timeoutSettings.TimeoutSettings.timeout(options));
+  async connectOverCDP(progress, endpointURL, options) {
+    return await this._connectOverCDPInternal(progress, endpointURL, options);
   }
   async _connectOverCDPInternal(progress, endpointURL, options, onClose) {
     let headersMap;
@@ -77,53 +71,67 @@ class Chromium extends import_browserType.BrowserType {
       headersMap = { "User-Agent": (0, import_userAgent.getUserAgent)() };
     else if (headersMap && !Object.keys(headersMap).some((key) => key.toLowerCase() === "user-agent"))
       headersMap["User-Agent"] = (0, import_userAgent.getUserAgent)();
-    const artifactsDir = await import_fs.default.promises.mkdtemp(ARTIFACTS_FOLDER);
-    const wsEndpoint = await urlToWSEndpoint(progress, endpointURL, headersMap);
-    progress.throwIfAborted();
-    const chromeTransport = await import_transport.WebSocketTransport.connect(progress, wsEndpoint, { headers: headersMap });
-    const cleanedUp = new import_manualPromise.ManualPromise();
+    const artifactsDir = await progress.race(import_fs.default.promises.mkdtemp(ARTIFACTS_FOLDER));
     const doCleanup = async () => {
       await (0, import_fileUtils.removeFolders)([artifactsDir]);
-      await onClose?.();
-      cleanedUp.resolve();
+      const cb = onClose;
+      onClose = void 0;
+      await cb?.();
     };
+    let chromeTransport;
     const doClose = async () => {
-      await chromeTransport.closeAndWait();
-      await cleanedUp;
+      await chromeTransport?.closeAndWait();
+      await doCleanup();
     };
-    const browserProcess = { close: doClose, kill: doClose };
-    const persistent = { noDefaultViewport: true };
-    const browserOptions = {
-      slowMo: options.slowMo,
-      name: "chromium",
-      isChromium: true,
-      persistent,
-      browserProcess,
-      protocolLogger: import_helper.helper.debugProtocolLogger(),
-      browserLogsCollector: new import_debugLogger.RecentLogsCollector(),
-      artifactsDir,
-      downloadsPath: options.downloadsPath || artifactsDir,
-      tracesDir: options.tracesDir || artifactsDir,
-      originalLaunchOptions: {}
-    };
-    (0, import_browserContext.validateBrowserContextOptions)(persistent, browserOptions);
-    progress.throwIfAborted();
-    const browser = await import_crBrowser.CRBrowser.connect(this.attribution.playwright, chromeTransport, browserOptions);
-    browser._isCollocatedWithServer = false;
-    browser.on(import_browser.Browser.Events.Disconnected, doCleanup);
-    return browser;
+    try {
+      const wsEndpoint = await urlToWSEndpoint(progress, endpointURL, headersMap);
+      chromeTransport = await import_transport.WebSocketTransport.connect(progress, wsEndpoint, { headers: headersMap });
+      const browserProcess = { close: doClose, kill: doClose };
+      const persistent = { noDefaultViewport: true };
+      const browserOptions = {
+        slowMo: options.slowMo,
+        name: "chromium",
+        isChromium: true,
+        persistent,
+        browserProcess,
+        protocolLogger: import_helper.helper.debugProtocolLogger(),
+        browserLogsCollector: new import_debugLogger.RecentLogsCollector(),
+        artifactsDir,
+        downloadsPath: options.downloadsPath || artifactsDir,
+        tracesDir: options.tracesDir || artifactsDir,
+        originalLaunchOptions: {}
+      };
+      (0, import_browserContext.validateBrowserContextOptions)(persistent, browserOptions);
+      const browser = await progress.race(import_crBrowser.CRBrowser.connect(this.attribution.playwright, chromeTransport, browserOptions));
+      browser._isCollocatedWithServer = false;
+      browser.on(import_browser.Browser.Events.Disconnected, doCleanup);
+      return browser;
+    } catch (error) {
+      await doClose().catch(() => {
+      });
+      throw error;
+    }
   }
   _createDevTools() {
     const directory = import_registry.registry.findExecutable("chromium").directory;
     return directory ? new import_crDevTools.CRDevTools(import_path.default.join(directory, "devtools-preferences.json")) : void 0;
   }
-  async connectToTransport(transport, options) {
+  async connectToTransport(transport, options, browserLogsCollector) {
     let devtools = this._devtools;
     if (options.__testHookForDevTools) {
       devtools = this._createDevTools();
       await options.__testHookForDevTools(devtools);
     }
-    return import_crBrowser.CRBrowser.connect(this.attribution.playwright, transport, options, devtools);
+    try {
+      return await import_crBrowser.CRBrowser.connect(this.attribution.playwright, transport, options, devtools);
+    } catch (e) {
+      if (browserLogsCollector.recentLogs().some((log) => log.includes("Failed to create a ProcessSingleton for your profile directory."))) {
+        throw new Error(
+          "Failed to create a ProcessSingleton for your profile directory. This usually means that the profile is already in use by another instance of Chromium."
+        );
+      }
+      throw e;
+    }
   }
   doRewriteStartupLog(error) {
     if (!error.logs)
@@ -143,7 +151,7 @@ class Chromium extends import_browserType.BrowserType {
     ].join("\n");
     return error;
   }
-  amendEnvironment(env, userDataDir, executable, browserArguments) {
+  amendEnvironment(env) {
     return env;
   }
   attemptToGracefullyCloseBrowser(transport) {
@@ -151,7 +159,7 @@ class Chromium extends import_browserType.BrowserType {
     transport.send(message);
   }
   async _launchWithSeleniumHub(progress, hubUrl, options) {
-    await this._createArtifactDirs(options);
+    await progress.race(this._createArtifactDirs(options));
     if (!hubUrl.endsWith("/"))
       hubUrl = hubUrl + "/";
     const args = this._innerDefaultArgs(options);
@@ -173,7 +181,7 @@ class Chromium extends import_browserType.BrowserType {
         headers = remoteHeaders;
     }
     progress.log(`<selenium> connecting to ${hubUrl}`);
-    const response = await (0, import_network.fetchData)({
+    const response = await (0, import_network.fetchData)(progress, {
       url: hubUrl + "session",
       method: "POST",
       headers: {
@@ -182,15 +190,14 @@ class Chromium extends import_browserType.BrowserType {
       },
       data: JSON.stringify({
         capabilities: { alwaysMatch: desiredCapabilities }
-      }),
-      timeout: progress.timeUntilDeadline()
+      })
     }, seleniumErrorHandler);
     const value = JSON.parse(response).value;
     const sessionId = value.sessionId;
     progress.log(`<selenium> connected to sessionId=${sessionId}`);
     const disconnectFromSelenium = async () => {
       progress.log(`<selenium> disconnecting from sessionId=${sessionId}`);
-      await (0, import_network.fetchData)({
+      await (0, import_network.fetchData)(void 0, {
         url: hubUrl + "session/" + sessionId,
         method: "DELETE",
         headers
@@ -221,10 +228,9 @@ class Chromium extends import_browserType.BrowserType {
         if (endpointURL.hostname === "localhost" || endpointURL.hostname === "127.0.0.1") {
           const sessionInfoUrl = new URL(hubUrl).origin + "/grid/api/testsession?session=" + sessionId;
           try {
-            const sessionResponse = await (0, import_network.fetchData)({
+            const sessionResponse = await (0, import_network.fetchData)(progress, {
               url: sessionInfoUrl,
               method: "GET",
-              timeout: progress.timeUntilDeadline(),
               headers
             }, seleniumErrorHandler);
             const proxyId = JSON.parse(sessionResponse).proxyId;
@@ -244,11 +250,11 @@ class Chromium extends import_browserType.BrowserType {
       throw e;
     }
   }
-  defaultArgs(options, isPersistent, userDataDir) {
+  async defaultArgs(options, isPersistent, userDataDir) {
     const chromeArguments = this._innerDefaultArgs(options);
     chromeArguments.push(`--user-data-dir=${userDataDir}`);
-    if (options.useWebSocket)
-      chromeArguments.push("--remote-debugging-port=0");
+    if (options.cdpPort !== void 0)
+      chromeArguments.push(`--remote-debugging-port=${options.cdpPort}`);
     else
       chromeArguments.push("--remote-debugging-pipe");
     if (isPersistent)
@@ -266,11 +272,9 @@ class Chromium extends import_browserType.BrowserType {
       throw new Error("Playwright manages remote debugging connection itself.");
     if (args.find((arg) => !arg.startsWith("-")))
       throw new Error("Arguments can not specify page to be opened");
-    const chromeArguments = [...import_chromiumSwitches.chromiumSwitches];
+    const chromeArguments = [...(0, import_chromiumSwitches.chromiumSwitches)(options.assistantMode, options.channel)];
     if (import_os.default.platform() === "darwin") {
-      chromeArguments.push("--enable-use-zoom-for-dsf=false");
-      if (options.headless && (!options.channel || options.channel === "chromium-headless-shell"))
-        chromeArguments.push("--use-angle");
+      chromeArguments.push("--enable-unsafe-swiftshader");
     }
     if (options.devtools)
       chromeArguments.push("--auto-open-devtools-for-tabs");
@@ -288,12 +292,12 @@ class Chromium extends import_browserType.BrowserType {
     if (proxy) {
       const proxyURL = new URL(proxy.server);
       const isSocks = proxyURL.protocol === "socks5:";
-      if (isSocks && !this.attribution.playwright.options.socksProxyPort) {
+      if (isSocks && !options.socksProxyPort) {
         chromeArguments.push(`--host-resolver-rules="MAP * ~NOTFOUND , EXCLUDE ${proxyURL.hostname}"`);
       }
       chromeArguments.push(`--proxy-server=${proxy.server}`);
       const proxyBypassRules = [];
-      if (this.attribution.playwright.options.socksProxyPort)
+      if (options.socksProxyPort)
         proxyBypassRules.push("<-loopback>");
       if (proxy.bypass)
         proxyBypassRules.push(...proxy.bypass.split(",").map((t) => t.trim()).map((t) => t.startsWith(".") ? "*" + t : t));
@@ -305,10 +309,8 @@ class Chromium extends import_browserType.BrowserType {
     chromeArguments.push(...args);
     return chromeArguments;
   }
-  readyState(options) {
-    if (options.useWebSocket || options.args?.some((a) => a.startsWith("--remote-debugging-port")))
-      return new ChromiumReadyState();
-    return void 0;
+  async waitForReadyState(options, browserLogsCollector) {
+    return waitForReadyState(options, browserLogsCollector);
   }
   getExecutableName(options) {
     if (options.channel)
@@ -316,19 +318,31 @@ class Chromium extends import_browserType.BrowserType {
     return options.headless ? "chromium-headless-shell" : "chromium";
   }
 }
-class ChromiumReadyState extends import_browserType2.BrowserReadyState {
-  onBrowserOutput(message) {
+async function waitForReadyState(options, browserLogsCollector) {
+  if (options.cdpPort === void 0 && !options.args?.some((a) => a.startsWith("--remote-debugging-port")))
+    return {};
+  const result = new import_manualPromise.ManualPromise();
+  browserLogsCollector.onMessage((message) => {
+    if (message.includes("Failed to create a ProcessSingleton for your profile directory.")) {
+      result.reject(new Error("Failed to create a ProcessSingleton for your profile directory. This usually means that the profile is already in use by another instance of Chromium."));
+    }
     const match = message.match(/DevTools listening on (.*)/);
     if (match)
-      this._wsEndpoint.resolve(match[1]);
-  }
+      result.resolve({ wsEndpoint: match[1] });
+  });
+  return result;
 }
 async function urlToWSEndpoint(progress, endpointURL, headers) {
   if (endpointURL.startsWith("ws"))
     return endpointURL;
   progress.log(`<ws preparing> retrieving websocket url from ${endpointURL}`);
-  const httpURL = endpointURL.endsWith("/") ? `${endpointURL}json/version/` : `${endpointURL}/json/version/`;
+  const url = new URL(endpointURL);
+  if (!url.pathname.endsWith("/"))
+    url.pathname += "/";
+  url.pathname += "json/version/";
+  const httpURL = url.toString();
   const json = await (0, import_network.fetchData)(
+    progress,
     {
       url: httpURL,
       headers
@@ -372,5 +386,6 @@ function parseSeleniumRemoteParams(env, progress) {
 }
 // Annotate the CommonJS export names for ESM import in node:
 0 && (module.exports = {
-  Chromium
+  Chromium,
+  waitForReadyState
 });
