@@ -51,7 +51,6 @@ class CRBrowser extends import_browser.Browser {
     this._clientRootSessionPromise = null;
     this._contexts = /* @__PURE__ */ new Map();
     this._crPages = /* @__PURE__ */ new Map();
-    this._backgroundPages = /* @__PURE__ */ new Map();
     this._serviceWorkers = /* @__PURE__ */ new Map();
     this._version = "";
     this._tracingRecording = false;
@@ -133,7 +132,7 @@ class CRBrowser extends import_browser.Browser {
   async _waitForAllPagesToBeInitialized() {
     await Promise.all([...this._crPages.values()].map((crPage) => crPage._page.waitForInitializedOrError()));
   }
-  _onAttachedToTarget({ targetInfo, sessionId }) {
+  _onAttachedToTarget({ targetInfo, sessionId, waitingForDebugger }) {
     if (targetInfo.type === "browser")
       return;
     const session = this._session.createChildSession(sessionId);
@@ -153,16 +152,10 @@ class CRBrowser extends import_browser.Browser {
       return;
     }
     (0, import_assert.assert)(!this._crPages.has(targetInfo.targetId), "Duplicate target " + targetInfo.targetId);
-    (0, import_assert.assert)(!this._backgroundPages.has(targetInfo.targetId), "Duplicate target " + targetInfo.targetId);
     (0, import_assert.assert)(!this._serviceWorkers.has(targetInfo.targetId), "Duplicate target " + targetInfo.targetId);
-    if (targetInfo.type === "background_page") {
-      const backgroundPage = new import_crPage.CRPage(session, targetInfo.targetId, context, null, { hasUIWindow: false, isBackgroundPage: true });
-      this._backgroundPages.set(targetInfo.targetId, backgroundPage);
-      return;
-    }
     if (targetInfo.type === "page" || treatOtherAsPage) {
       const opener = targetInfo.openerId ? this._crPages.get(targetInfo.openerId) || null : null;
-      const crPage = new import_crPage.CRPage(session, targetInfo.targetId, context, opener, { hasUIWindow: targetInfo.type === "page", isBackgroundPage: false });
+      const crPage = new import_crPage.CRPage(session, targetInfo.targetId, context, opener, { hasUIWindow: targetInfo.type === "page" });
       this._crPages.set(targetInfo.targetId, crPage);
       return;
     }
@@ -183,12 +176,6 @@ class CRBrowser extends import_browser.Browser {
       crPage.didClose();
       return;
     }
-    const backgroundPage = this._backgroundPages.get(targetId);
-    if (backgroundPage) {
-      this._backgroundPages.delete(targetId);
-      backgroundPage.didClose();
-      return;
-    }
     const serviceWorker = this._serviceWorkers.get(targetId);
     if (serviceWorker) {
       this._serviceWorkers.delete(targetId);
@@ -200,9 +187,6 @@ class CRBrowser extends import_browser.Browser {
     for (const crPage of this._crPages.values())
       crPage.didClose();
     this._crPages.clear();
-    for (const backgroundPage of this._backgroundPages.values())
-      backgroundPage.didClose();
-    this._backgroundPages.clear();
     for (const serviceWorker of this._serviceWorkers.values())
       serviceWorker.didClose();
     this._serviceWorkers.clear();
@@ -295,7 +279,6 @@ class CRBrowser extends import_browser.Browser {
 class CRBrowserContext extends import_browserContext.BrowserContext {
   static {
     this.CREvents = {
-      BackgroundPage: "backgroundpage",
       ServiceWorker: "serviceworker"
     };
   }
@@ -481,12 +464,6 @@ class CRBrowserContext extends import_browserContext.BrowserContext {
     await Promise.all(this._crPages().map((crPage) => crPage._mainFrameSession._stopVideoRecording()));
   }
   onClosePersistent() {
-    for (const [targetId, backgroundPage] of this._browser._backgroundPages.entries()) {
-      if (backgroundPage._browserContext === this && backgroundPage._page.initializedOrUndefined()) {
-        backgroundPage.didClose();
-        this._browser._backgroundPages.delete(targetId);
-      }
-    }
   }
   async clearCache() {
     for (const page of this._crPages())
@@ -498,14 +475,6 @@ class CRBrowserContext extends import_browserContext.BrowserContext {
       browserContextId: this._browserContextId
     });
   }
-  backgroundPages() {
-    const result = [];
-    for (const backgroundPage of this._browser._backgroundPages.values()) {
-      if (backgroundPage._browserContext === this && backgroundPage._page.initializedOrUndefined())
-        result.push(backgroundPage._page);
-    }
-    return result;
-  }
   serviceWorkers() {
     return Array.from(this._browser._serviceWorkers.values()).filter((serviceWorker) => serviceWorker.browserContext === this);
   }
