@@ -103,6 +103,19 @@ class PageDispatcher extends import_dispatcher.Dispatcher {
   page() {
     return this._page;
   }
+  serializeConsoleMessage(message) {
+    return {
+      type: message.type(),
+      text: message.text(),
+      args: message.args().map((a) => {
+        const elementHandle = a.asElement();
+        if (elementHandle)
+          return import_elementHandlerDispatcher.ElementHandleDispatcher.from(import_frameDispatcher.FrameDispatcher.from(this.parentScope(), elementHandle._frame), elementHandle);
+        return import_jsHandleDispatcher.JSHandleDispatcher.fromJSHandle(this, a);
+      }),
+      location: message.location()
+    };
+  }
   async exposeBinding(params, progress) {
     const binding = await this._page.exposeBinding(progress, params.name, !!params.needsHandle, (source, ...args) => {
       if (this._disposed)
@@ -222,6 +235,13 @@ class PageDispatcher extends import_dispatcher.Dispatcher {
   async keyboardPress(params, progress) {
     await this._page.keyboard.press(progress, params.key, params);
   }
+  async consoleMessages(params, progress) {
+    this._subscriptions.add("console");
+    return { messages: this._page.consoleMessages().map((message) => this.serializeConsoleMessage(message)) };
+  }
+  async pageErrors(params, progress) {
+    return { errors: this._page.pageErrors().map((error) => (0, import_errors.serializeError)(error)) };
+  }
   async mouseMove(params, progress) {
     progress.metadata.point = { x: params.x, y: params.y };
     await this._page.mouse.move(progress, params.x, params.y, params);
@@ -258,6 +278,10 @@ class PageDispatcher extends import_dispatcher.Dispatcher {
     const buffer = await progress.race(this._page.pdf(params));
     return { pdf: buffer };
   }
+  async requests(params, progress) {
+    this._subscriptions.add("request");
+    return { requests: this._page.networkRequests().map((request) => import_networkDispatchers.RequestDispatcher.from(this.parentScope(), request)) };
+  }
   async snapshotForAI(params, progress) {
     return { snapshot: await this._page.snapshotForAI(progress) };
   }
