@@ -84,6 +84,7 @@ class FrameExecutionContext extends js.ExecutionContext {
         testIdAttributeName: selectorsRegistry.testIdAttributeName(),
         stableRafCount: this.frame._page.delegate.rafCountForStablePosition(),
         browserName: this.frame._page.browserContext._browser.options.name,
+        isUtilityWorld: this.world === "utility",
         customEngines
       };
       const source = `
@@ -635,17 +636,21 @@ class ElementHandle extends js.JSHandle {
       const result2 = await progress.race(this.evaluateInUtility(([injected, node]) => injected.elementState(node, "checked"), {}));
       if (result2 === "error:notconnected" || result2.received === "error:notconnected")
         throwElementIsNotAttached();
-      return result2.matches;
+      return { matches: result2.matches, isRadio: result2.isRadio };
     };
     await this._markAsTargetElement(progress);
-    if (await isChecked() === state)
+    const checkedState = await isChecked();
+    if (checkedState.matches === state)
       return "done";
+    if (!state && checkedState.isRadio)
+      throw new NonRecoverableDOMError("Cannot uncheck radio button. Radio buttons can only be unchecked by selecting another radio button in the same group.");
     const result = await this._click(progress, { ...options, waitAfter: "disabled" });
     if (result !== "done")
       return result;
     if (options.trial)
       return "done";
-    if (await isChecked() !== state)
+    const finalState = await isChecked();
+    if (finalState.matches !== state)
       throw new NonRecoverableDOMError("Clicking the checkbox did not change its state");
     return "done";
   }
