@@ -44,7 +44,6 @@ var import_ffInput = require("./ffInput");
 var import_ffNetworkManager = require("./ffNetworkManager");
 var import_debugLogger = require("../utils/debugLogger");
 var import_stackTrace = require("../../utils/isomorphic/stackTrace");
-var import_browserContext = require("../browserContext");
 var import_errors = require("../errors");
 const UTILITY_WORLD_NAME = "__playwright_utility_world__";
 class FFPage {
@@ -98,7 +97,7 @@ class FFPage {
       this._reportedAsNew = true;
       this._page.reportAsNew(this._opener?._page);
     });
-    this.addInitScript(new import_page.InitScript("", true), UTILITY_WORLD_NAME).catch((e) => this._markAsError(e));
+    this.addInitScript(new import_page.InitScript(""), UTILITY_WORLD_NAME).catch((e) => this._markAsError(e));
   }
   async _markAsError(error) {
     if (this._reportedAsNew)
@@ -107,23 +106,23 @@ class FFPage {
     this._page.reportAsNew(this._opener?._page, error);
   }
   _onWebSocketCreated(event) {
-    this._page._frameManager.onWebSocketCreated(webSocketId(event.frameId, event.wsid), event.requestURL);
-    this._page._frameManager.onWebSocketRequest(webSocketId(event.frameId, event.wsid));
+    this._page.frameManager.onWebSocketCreated(webSocketId(event.frameId, event.wsid), event.requestURL);
+    this._page.frameManager.onWebSocketRequest(webSocketId(event.frameId, event.wsid));
   }
   _onWebSocketClosed(event) {
     if (event.error)
-      this._page._frameManager.webSocketError(webSocketId(event.frameId, event.wsid), event.error);
-    this._page._frameManager.webSocketClosed(webSocketId(event.frameId, event.wsid));
+      this._page.frameManager.webSocketError(webSocketId(event.frameId, event.wsid), event.error);
+    this._page.frameManager.webSocketClosed(webSocketId(event.frameId, event.wsid));
   }
   _onWebSocketFrameReceived(event) {
-    this._page._frameManager.webSocketFrameReceived(webSocketId(event.frameId, event.wsid), event.opcode, event.data);
+    this._page.frameManager.webSocketFrameReceived(webSocketId(event.frameId, event.wsid), event.opcode, event.data);
   }
   _onWebSocketFrameSent(event) {
-    this._page._frameManager.onWebSocketFrameSent(webSocketId(event.frameId, event.wsid), event.opcode, event.data);
+    this._page.frameManager.onWebSocketFrameSent(webSocketId(event.frameId, event.wsid), event.opcode, event.data);
   }
   _onExecutionContextCreated(payload) {
     const { executionContextId, auxData } = payload;
-    const frame = this._page._frameManager.frame(auxData.frameId);
+    const frame = this._page.frameManager.frame(auxData.frameId);
     if (!frame)
       return;
     const delegate = new import_ffExecutionContext.FFExecutionContext(this._session, executionContextId);
@@ -157,55 +156,55 @@ class FFPage {
   }
   _onLinkClicked(phase) {
     if (phase === "before")
-      this._page._frameManager.frameWillPotentiallyRequestNavigation();
+      this._page.frameManager.frameWillPotentiallyRequestNavigation();
     else
-      this._page._frameManager.frameDidPotentiallyRequestNavigation();
+      this._page.frameManager.frameDidPotentiallyRequestNavigation();
   }
   _onNavigationStarted(params) {
-    this._page._frameManager.frameRequestedNavigation(params.frameId, params.navigationId);
+    this._page.frameManager.frameRequestedNavigation(params.frameId, params.navigationId);
   }
   _onNavigationAborted(params) {
-    this._page._frameManager.frameAbortedNavigation(params.frameId, params.errorText, params.navigationId);
+    this._page.frameManager.frameAbortedNavigation(params.frameId, params.errorText, params.navigationId);
   }
   _onNavigationCommitted(params) {
     for (const [workerId, worker] of this._workers) {
       if (worker.frameId === params.frameId)
         this._onWorkerDestroyed({ workerId });
     }
-    this._page._frameManager.frameCommittedNewDocumentNavigation(params.frameId, params.url, params.name || "", params.navigationId || "", false);
+    this._page.frameManager.frameCommittedNewDocumentNavigation(params.frameId, params.url, params.name || "", params.navigationId || "", false);
   }
   _onSameDocumentNavigation(params) {
-    this._page._frameManager.frameCommittedSameDocumentNavigation(params.frameId, params.url);
+    this._page.frameManager.frameCommittedSameDocumentNavigation(params.frameId, params.url);
   }
   _onFrameAttached(params) {
-    this._page._frameManager.frameAttached(params.frameId, params.parentFrameId);
+    this._page.frameManager.frameAttached(params.frameId, params.parentFrameId);
   }
   _onFrameDetached(params) {
-    this._page._frameManager.frameDetached(params.frameId);
+    this._page.frameManager.frameDetached(params.frameId);
   }
   _onEventFired(payload) {
     const { frameId, name } = payload;
     if (name === "load")
-      this._page._frameManager.frameLifecycleEvent(frameId, "load");
+      this._page.frameManager.frameLifecycleEvent(frameId, "load");
     if (name === "DOMContentLoaded")
-      this._page._frameManager.frameLifecycleEvent(frameId, "domcontentloaded");
+      this._page.frameManager.frameLifecycleEvent(frameId, "domcontentloaded");
   }
   _onUncaughtError(params) {
     const { name, message } = (0, import_stackTrace.splitErrorMessage)(params.message);
     const error = new Error(message);
     error.stack = params.message + "\n" + params.stack.split("\n").filter(Boolean).map((a) => a.replace(/([^@]*)@(.*)/, "    at $1 ($2)")).join("\n");
     error.name = name;
-    this._page.emitOnContextOnceInitialized(import_browserContext.BrowserContext.Events.PageError, error, this._page);
+    this._page.addPageError(error);
   }
   _onConsole(payload) {
     const { type, args, executionContextId, location } = payload;
     const context = this._contextIdToContext.get(executionContextId);
     if (!context)
       return;
-    this._page._addConsoleMessage(type === "warn" ? "warning" : type, args.map((arg) => (0, import_ffExecutionContext.createHandle)(context, arg)), location);
+    this._page.addConsoleMessage(type === "warn" ? "warning" : type, args.map((arg) => (0, import_ffExecutionContext.createHandle)(context, arg)), location);
   }
   _onDialogOpened(params) {
-    this._page.emitOnContext(import_browserContext.BrowserContext.Events.Dialog, new dialog.Dialog(
+    this._page.browserContext.dialogManager.dialogDidOpen(new dialog.Dialog(
       this._page,
       params.type,
       params.message,
@@ -220,7 +219,7 @@ class FFPage {
     if (!(pageOrError instanceof Error)) {
       const context = this._contextIdToContext.get(event.executionContextId);
       if (context)
-        await this._page._onBindingCalled(event.payload, context);
+        await this._page.onBindingCalled(event.payload, context);
     }
   }
   async _onFileChooserOpened(payload) {
@@ -244,14 +243,14 @@ class FFPage {
       });
     });
     this._workers.set(workerId, { session: workerSession, frameId: event.frameId });
-    this._page._addWorker(workerId, worker);
+    this._page.addWorker(workerId, worker);
     workerSession.once("Runtime.executionContextCreated", (event2) => {
-      worker._createExecutionContext(new import_ffExecutionContext.FFExecutionContext(workerSession, event2.executionContextId));
+      worker.createExecutionContext(new import_ffExecutionContext.FFExecutionContext(workerSession, event2.executionContextId));
     });
     workerSession.on("Runtime.console", (event2) => {
       const { type, args, location } = event2;
-      const context = worker._existingExecutionContext;
-      this._page._addConsoleMessage(type, args.map((arg) => (0, import_ffExecutionContext.createHandle)(context, arg)), location);
+      const context = worker.existingExecutionContext;
+      this._page.addConsoleMessage(type, args.map((arg) => (0, import_ffExecutionContext.createHandle)(context, arg)), location);
     });
   }
   _onWorkerDestroyed(event) {
@@ -261,7 +260,7 @@ class FFPage {
       return;
     worker.session.dispose();
     this._workers.delete(workerId);
-    this._page._removeWorker(workerId);
+    this._page.removeWorker(workerId);
   }
   async _onDispatchMessageFromWorker(event) {
     const worker = this._workers.get(event.workerId);
@@ -291,7 +290,7 @@ class FFPage {
     await this._session.send("Network.setExtraHTTPHeaders", { headers: this._page.extraHTTPHeaders() || [] });
   }
   async updateEmulatedViewportSize() {
-    const viewportSize = this._page.viewportSize();
+    const viewportSize = this._page.emulatedSize()?.viewport ?? null;
     await this._session.send("Page.setViewportSize", { viewportSize });
   }
   async bringToFront() {
@@ -336,10 +335,14 @@ class FFPage {
   }
   async addInitScript(initScript, worldName) {
     this._initScripts.push({ initScript, worldName });
-    await this._session.send("Page.setInitScripts", { scripts: this._initScripts.map((s) => ({ script: s.initScript.source, worldName: s.worldName })) });
+    await this._updateInitScripts();
   }
-  async removeNonInternalInitScripts() {
-    this._initScripts = this._initScripts.filter((s) => s.initScript.internal);
+  async removeInitScripts(initScripts) {
+    const set = new Set(initScripts);
+    this._initScripts = this._initScripts.filter((s) => !set.has(s.initScript));
+    await this._updateInitScripts();
+  }
+  async _updateInitScripts() {
     await this._session.send("Page.setInitScripts", { scripts: this._initScripts.map((s) => ({ script: s.initScript.source, worldName: s.worldName })) });
   }
   async closePage(runBeforeUnload) {
@@ -359,13 +362,12 @@ class FFPage {
         height: viewportRect.height
       };
     }
-    progress.throwIfAborted();
-    const { data } = await this._session.send("Page.screenshot", {
+    const { data } = await progress.race(this._session.send("Page.screenshot", {
       mimeType: "image/" + format,
       clip: documentRect,
       quality,
       omitDeviceScaleFactor: scale === "css"
-    });
+    }));
     return Buffer.from(data, "base64");
   }
   async getContentFrame(handle) {
@@ -375,7 +377,7 @@ class FFPage {
     });
     if (!contentFrameId)
       return null;
-    return this._page._frameManager.frame(contentFrameId);
+    return this._page.frameManager.frame(contentFrameId);
   }
   async getOwnerFrame(handle) {
     const { ownerFrameId } = await this._session.send("Page.describeNode", {
@@ -471,8 +473,8 @@ class FFPage {
   }
   async inputActionEpilogue() {
   }
-  async resetForReuse() {
-    await this.rawMouse.move(-1, -1, "none", /* @__PURE__ */ new Set(), /* @__PURE__ */ new Set(), false);
+  async resetForReuse(progress) {
+    await this.rawMouse.move(progress, -1, -1, "none", /* @__PURE__ */ new Set(), /* @__PURE__ */ new Set(), false);
   }
   async getFrameElement(frame) {
     const parent = frame.parentFrame();
