@@ -39,7 +39,6 @@ var import_eventsHelper = require("../utils/eventsHelper");
 var import_hostPlatform = require("../utils/hostPlatform");
 var import_stackTrace = require("../../utils/isomorphic/stackTrace");
 var import_utilsBundle = require("../../utilsBundle");
-var import_browserContext = require("../browserContext");
 var dialog = __toESM(require("../dialog"));
 var dom = __toESM(require("../dom"));
 var import_errors = require("../errors");
@@ -54,6 +53,7 @@ var import_wkInterceptableRequest = require("./wkInterceptableRequest");
 var import_wkProvisionalPage = require("./wkProvisionalPage");
 var import_wkWorkers = require("./wkWorkers");
 var import_debugLogger = require("../utils/debugLogger");
+var import_webkit = require("./webkit");
 const UTILITY_WORLD_NAME = "__playwright_utility_world__";
 class WKPage {
   constructor(browserContext, pageProxySession, opener) {
@@ -92,6 +92,8 @@ class WKPage {
       this._firstNonInitialNavigationCommittedFulfill = f;
       this._firstNonInitialNavigationCommittedReject = r;
     });
+    this._firstNonInitialNavigationCommittedPromise.catch(() => {
+    });
     if (opener && !browserContext._options.noDefaultViewport && opener._nextWindowOpenPopupFeatures) {
       const viewportSize = import_helper.helper.getViewportSizeFromWindowFeatures(opener._nextWindowOpenPopupFeatures);
       opener._nextWindowOpenPopupFeatures = void 0;
@@ -100,7 +102,7 @@ class WKPage {
     }
   }
   async _initializePageProxySession() {
-    if (this._page.browserContext.isSettingStorageState())
+    if (this._page.isStorageStatePage)
       return;
     const promises = [
       this._pageProxySession.send("Dialog.enable"),
@@ -169,7 +171,7 @@ class WKPage {
       promises.push(session.send("Network.setResourceCachingDisabled", { disabled: true }));
       promises.push(session.send("Network.addInterception", { url: ".*", stage: "request", isRegex: true }));
     }
-    if (this._page.browserContext.isSettingStorageState()) {
+    if (this._page.isStorageStatePage) {
       await Promise.all(promises);
       return;
     }
@@ -287,6 +289,8 @@ class WKPage {
         session.dispatchMessage({ id: message.id, error: { message: e.message } });
       });
     });
+    if (targetInfo.type === "frame")
+      return;
     (0, import_utils.assert)(targetInfo.type === "page", "Only page targets are expected in WebKit, received: " + targetInfo.type);
     if (!targetInfo.isProvisional) {
       (0, import_utils.assert)(!this._page.initializedOrUndefined());
@@ -309,9 +313,6 @@ class WKPage {
         } catch (e) {
           pageOrError = e;
         }
-      } else {
-        this._firstNonInitialNavigationCommittedPromise.catch(() => {
-        });
       }
       this._page.reportAsNew(this._opener?._page, pageOrError instanceof import_page.Page ? void 0 : pageOrError);
     } else {
@@ -342,7 +343,6 @@ class WKPage {
       import_eventsHelper.eventsHelper.addEventListener(this._session, "Page.frameDetached", (event) => this._onFrameDetached(event.frameId)),
       import_eventsHelper.eventsHelper.addEventListener(this._session, "Page.willCheckNavigationPolicy", (event) => this._onWillCheckNavigationPolicy(event.frameId)),
       import_eventsHelper.eventsHelper.addEventListener(this._session, "Page.didCheckNavigationPolicy", (event) => this._onDidCheckNavigationPolicy(event.frameId, event.cancel)),
-      import_eventsHelper.eventsHelper.addEventListener(this._session, "Page.frameScheduledNavigation", (event) => this._onFrameScheduledNavigation(event.frameId, event.delay, event.targetIsCurrentFrame)),
       import_eventsHelper.eventsHelper.addEventListener(this._session, "Page.loadEventFired", (event) => this._page.frameManager.frameLifecycleEvent(event.frameId, "load")),
       import_eventsHelper.eventsHelper.addEventListener(this._session, "Page.domContentEventFired", (event) => this._page.frameManager.frameLifecycleEvent(event.frameId, "domcontentloaded")),
       import_eventsHelper.eventsHelper.addEventListener(this._session, "Runtime.executionContextCreated", (event) => this._onExecutionContextCreated(event.context)),
@@ -389,10 +389,6 @@ class WKPage {
       return;
     this._page.frameManager.frameAbortedNavigation(frameId, "Navigation canceled by policy check");
   }
-  _onFrameScheduledNavigation(frameId, delay, targetIsCurrentFrame) {
-    if (targetIsCurrentFrame)
-      this._page.frameManager.frameRequestedNavigation(frameId);
-  }
   _handleFrameTree(frameTree) {
     this._onFrameAttached(frameTree.frame.id, frameTree.frame.parentId || null);
     this._onFrameNavigated(frameTree.frame, true);
@@ -479,7 +475,7 @@ class WKPage {
       const error = new Error(message);
       error.stack = stack;
       error.name = name;
-      this._page.emitOnContextOnceInitialized(import_browserContext.BrowserContext.Events.PageError, error, this._page);
+      this._page.addPageError(error);
       return;
     }
     let derivedType = type || "";
@@ -668,6 +664,8 @@ class WKPage {
       promises.push(this._pageProxySession.send("Emulation.setOrientationOverride", { angle }));
     }
     await Promise.all(promises);
+    if (!this._browserContext._browser?.options.headful && (import_hostPlatform.hostPlatform === "ubuntu22.04-x64" || import_hostPlatform.hostPlatform.startsWith("debian12")))
+      await new Promise((r) => setTimeout(r, 500));
   }
   async updateRequestInterception() {
     const enabled = this._page.needsRequestInterception();
@@ -768,7 +766,7 @@ class WKPage {
   async _startVideo(options) {
     (0, import_utils.assert)(!this._recordingVideoFile);
     const { screencastId } = await this._pageProxySession.send("Screencast.startVideo", {
-      file: options.outputFile,
+      file: this._browserContext._browser.options.channel === "webkit-wsl" ? await (0, import_webkit.translatePathToWSL)(options.outputFile) : options.outputFile,
       width: options.width,
       height: options.height,
       toolbarHeight: this._toolbarHeight()
@@ -888,6 +886,8 @@ class WKPage {
   async setInputFilePaths(handle, paths) {
     const pageProxyId = this._pageProxySession.sessionId;
     const objectId = handle._objectId;
+    if (this._browserContext._browser?.options.channel === "webkit-wsl")
+      paths = await Promise.all(paths.map((path2) => (0, import_webkit.translatePathToWSL)(path2)));
     await Promise.all([
       this._pageProxySession.connection.browserSession.send("Playwright.grantFileReadAccess", { pageProxyId, paths }),
       this._session.send("DOM.setInputFiles", { objectId, paths })
